==> kibana-7.17.13-darwin-aarch64.tar.gz: kibana-7.17.13-darwin-aarch64/x-pack/plugins/infra/common/http_api/infra_ml/results/metrics_hosts_anomalies.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMetricsHostsAnomaliesSuccessReponsePayloadRT = exports.getMetricsHostsAnomaliesRequestPayloadRT = exports.INFA_ML_GET_METRICS_HOSTS_ANOMALIES_PATH = void 0;
var rt = _interopRequireWildcard(require("io-ts"));
var _shared = require("../../shared");
var _common = require("./common");
function _getRequireWildcardCache(nodeInterop) {
  if (typeof WeakMap !== "function") return null;
  var cacheBabelInterop = new WeakMap();
  var cacheNodeInterop = new WeakMap();
  return (_getRequireWildcardCache = function (nodeInterop) {
    return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
  })(nodeInterop);
}
function _interopRequireWildcard(obj, nodeInterop) {
  if (!nodeInterop && obj && obj.__esModule) {
    return obj;
  }
  if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
    return {
      default: obj
    };
  }
  var cache = _getRequireWildcardCache(nodeInterop);
  if (cache && cache.has(obj)) {
    return cache.get(obj);
  }
  var newObj = {};
  var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var key in obj) {
    if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc);
      } else {
        newObj[key] = obj[key];
      }
    }
  }
  newObj.default = obj;
  if (cache) {
    cache.set(obj, newObj);
  }
  return newObj;
}
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const INFA_ML_GET_METRICS_HOSTS_ANOMALIES_PATH = '/api/infra/infra_ml/results/metrics_hosts_anomalies';
exports.INFA_ML_GET_METRICS_HOSTS_ANOMALIES_PATH = INFA_ML_GET_METRICS_HOSTS_ANOMALIES_PATH;
const metricsHostAnomalyCommonFieldsRT = rt.intersection([rt.type({
  id: rt.string,
  anomalyScore: rt.number,
  typical: rt.number,
  actual: rt.number,
  type: _common.anomalyTypeRT,
  influencers: rt.array(rt.string),
  duration: rt.number,
  startTime: rt.number,
  jobId: rt.string
}), rt.partial({
  partitionFieldName: rt.string,
  partitionFieldValue: rt.string
})]);
const metricsHostsAnomalyRT = metricsHostAnomalyCommonFieldsRT;
const getMetricsHostsAnomaliesSuccessReponsePayloadRT = rt.intersection([rt.type({
  data: rt.intersection([rt.type({
    anomalies: rt.array(metricsHostsAnomalyRT),
    // Signifies there are more entries backwards or forwards. If this was a request
    // for a previous page, there are more previous pages, if this was a request for a next page,
    // there are more next pages.
    hasMoreEntries: rt.boolean
  }), rt.partial({
    paginationCursors: rt.type({
      // The cursor to use to fetch the previous page
      previousPageCursor: _common.paginationCursorRT,
      // The cursor to use to fetch the next page
      nextPageCursor: _common.paginationCursorRT
    })
  })])
}), rt.partial({
  timing: _shared.routeTimingMetadataRT
})]);
exports.getMetricsHostsAnomaliesSuccessReponsePayloadRT = getMetricsHostsAnomaliesSuccessReponsePayloadRT;
const getMetricsHostsAnomaliesRequestPayloadRT = rt.type({
  data: rt.intersection([rt.type({
    // the ID of the source configuration
    sourceId: rt.string,
    anomalyThreshold: rt.number,
    // the time range to fetch the log entry anomalies from
    timeRange: _shared.timeRangeRT
  }), rt.partial({
    query: rt.string,
    hostName: rt.string,
    metric: _common.metricRT,
    // Pagination properties
    pagination: _common.paginationRT,
    // Sort properties
    sort: _common.sortRT
  })])
});
exports.getMetricsHostsAnomaliesRequestPayloadRT = getMetricsHostsAnomaliesRequestPayloadRT;

==> kibana-7.17.20-darwin-aarch64.tar.gz: kibana-7.17.20-darwin-aarch64/x-pack/plugins/infra/common/http_api/infra_ml/results/metrics_hosts_anomalies.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMetricsHostsAnomaliesSuccessReponsePayloadRT = exports.getMetricsHostsAnomaliesRequestPayloadRT = exports.INFA_ML_GET_METRICS_HOSTS_ANOMALIES_PATH = void 0;
var rt = _interopRequireWildcard(require("io-ts"));
var _shared = require("../../shared");
var _common = require("./common");
function _getRequireWildcardCache(e) {
  if ("function" != typeof WeakMap) return null;
  var r = new WeakMap(),
    t = new WeakMap();
  return (_getRequireWildcardCache = function (e) {
    return e ? t : r;
  })(e);
}
function _interopRequireWildcard(e, r) {
  if (!r && e && e.__esModule) return e;
  if (null === e || "object" != typeof e && "function" != typeof e) return {
    default: e
  };
  var t = _getRequireWildcardCache(r);
  if (t && t.has(e)) return t.get(e);
  var n = {
      __proto__: null
    },
    a = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) {
    var i = a ? Object.getOwnPropertyDescriptor(e, u) : null;
    i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u];
  }
  return n.default = e, t && t.set(e, n), n;
}
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const INFA_ML_GET_METRICS_HOSTS_ANOMALIES_PATH = exports.INFA_ML_GET_METRICS_HOSTS_ANOMALIES_PATH = '/api/infra/infra_ml/results/metrics_hosts_anomalies';
const metricsHostAnomalyCommonFieldsRT = rt.intersection([rt.type({
  id: rt.string,
  anomalyScore: rt.number,
  typical: rt.number,
  actual: rt.number,
  type: _common.anomalyTypeRT,
  influencers: rt.array(rt.string),
  duration: rt.number,
  startTime: rt.number,
  jobId: rt.string
}), rt.partial({
  partitionFieldName: rt.string,
  partitionFieldValue: rt.string
})]);
const metricsHostsAnomalyRT = metricsHostAnomalyCommonFieldsRT;
const getMetricsHostsAnomaliesSuccessReponsePayloadRT = exports.getMetricsHostsAnomaliesSuccessReponsePayloadRT = rt.intersection([rt.type({
  data: rt.intersection([rt.type({
    anomalies: rt.array(metricsHostsAnomalyRT),
    // Signifies there are more entries backwards or forwards. If this was a request
    // for a previous page, there are more previous pages, if this was a request for a next page,
    // there are more next pages.
    hasMoreEntries: rt.boolean
  }), rt.partial({
    paginationCursors: rt.type({
      // The cursor to use to fetch the previous page
      previousPageCursor: _common.paginationCursorRT,
      // The cursor to use to fetch the next page
      nextPageCursor: _common.paginationCursorRT
    })
  })])
}), rt.partial({
  timing: _shared.routeTimingMetadataRT
})]);
const getMetricsHostsAnomaliesRequestPayloadRT = exports.getMetricsHostsAnomaliesRequestPayloadRT = rt.type({
  data: rt.intersection([rt.type({
    // the ID of the source configuration
    sourceId: rt.string,
    anomalyThreshold: rt.number,
    // the time range to fetch the log entry anomalies from
    timeRange: _shared.timeRangeRT
  }), rt.partial({
    query: rt.string,
    hostName: rt.string,
    metric: _common.metricRT,
    // Pagination properties
    pagination: _common.paginationRT,
    // Sort properties
    sort: _common.sortRT
  })])
});
